==========
GenomeHubs
==========

.. start-badges

|travis| |coveralls|
|docs| |code-style|
|version| |conda| |commits-since|
|license|


.. |code-style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style Black

.. |docs| image:: https://readthedocs.org/projects/genomehubs/badge/?style=flat
    :target: https://readthedocs.org/projects/genomehubs
    :alt: Documentation Status

.. |travis| image:: https://api.travis-ci.org/genomehubs/genomehubs.svg?branch=main
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/genomehubs/genomehubs

.. |coveralls| image:: https://coveralls.io/repos/genomehubs/genomehubs/badge.svg?branch=main&service=github
    :alt: Coverage Status
    :target: https://coveralls.io/r/genomehubs/genomehubs

.. |version| image:: https://img.shields.io/pypi/v/genomehubs.svg
    :alt: PyPI Package latest release
    :target: https://pypi.org/project/genomehubs

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/genomehubs.svg
    :alt: Supported versions
    :target: https://pypi.org/project/genomehubs

.. |conda| image:: https://anaconda.org/tolkit/genomehubs/badges/installer/conda.svg
    :alt: Install with Conda
    :target: https://anaconda.org/tolkit/genomehubs

.. |platforms| image:: https://anaconda.org/tolkit/genomehubs/badges/platforms.svg
    :alt: Conda platforms
    :target: https://anaconda.org/tolkit/genomehubs

.. |commits-since| image:: https://img.shields.io/github/commits-since/genomehubs/genomehubs/2.5.33.svg
    :alt: Commits since latest release
    :target: https://github.com/genomehubs/genomehubs/compare/2.5.33...main

.. |license| image:: https://anaconda.org/tolkit/genomehubs/badges/license.svg
    :alt: MIT License
    :target: https://anaconda.org/tolkit/genomehubs

.. end-badges



Installation
============

::

    conda install -c tolkit genomehubs

or 

    pip install genomehubs

You can also install the in-development version with::

    pip install https://github.com/genomehubs/genomehubs/archive/main.zip


Documentation
=============


https://genomehubs.readthedocs.io/


Development
===========

To run all tests run::

    tox
